Hirda — LaVue 2.76.0 documentation

# Hirda

Images from a Hidra server, e.g. Pilatus or PerkinElmer detectors

The Hidra image source frame contains the following fields:

- Server: selects the Hidra server host name. The possible names can be predefined in the Configuration dialog.

- Client: shows the Hidra client host name and the data port. The data port can be changed in the Configuration dialog.

- Status: shows the Hidra connection status. It also displays a port of ZMQ security stream if it is enabled.

- Start/Stop button to launch or interrupt image querying